@@ -15,8 +15,5 @@ class Performance(Overview):
         """initiate module
         """
         self.BASE_URL = 'https://finviz.com/screener.ashx?v=141{signal}{filter}&ft=4{ticker}'
-        self.NUMBER_COL = ['Perf Week', 'Perf Month', 'Perf Quart', 'Perf Half',
-                           'Perf Year', 'Perf YTD', 'Volatility W', 'Volatility M',
-                           'Recom', 'Avg Volume', 'Rel Volume', 'Price', 'Change', 'Volume']
         self.url = self.BASE_URL.format(signal='', filter='', ticker='')
         Overview._loadSetting(self)
\ No newline at end of file
